# Metrics Frameworks

## AARRR (Pirate Metrics)

AARRR breaks the product journey into five stages.

1. Acquisition
- How users discover the product
- Example metrics: signups, CAC, channel conversion

2. Activation
- First meaningful value moment
- Example metrics: activation rate, time-to-first-value

3. Retention
- Ongoing user return behavior
- Example metrics: D7/W4 retention, rolling retained users

4. Revenue
- Monetization and value capture
- Example metrics: conversion to paid, ARPU, expansion revenue

5. Referral
- Organic growth from existing users
- Example metrics: referral rate, invite conversion, K-factor

## North Star Metric Framework

North Star = metric capturing long-term customer value delivered.

### North Star Criteria
- Reflects real user value
- Sensitive to product improvements
- Predictive of sustainable growth
- Understandable across functions

### Example North Star Metrics
- Collaboration SaaS: weekly active teams
- Marketplace: successful transactions per active buyer
- Content product: hours of qualified consumption

### Input Metrics
Track levers that influence the North Star:
- Acquisition quality
- Activation quality
- Engagement depth
- Retention durability

## HEART Framework

HEART is a UX-oriented framework from Google.

- Happiness: satisfaction, NPS, perceived quality
- Engagement: interaction depth/frequency
- Adoption: first-time use of features/products
- Retention: return behavior over time
- Task Success: completion rate, error rate, time on task

### HEART + Goals-Signals-Metrics
1. Goals: what UX outcome you want
2. Signals: observed behavior indicating movement
3. Metrics: measurable indicator for each signal

## Framework Selection Guide

| Situation | Recommended Framework |
|---|---|
| Early growth and funnel bottlenecks | AARRR |
| Company-wide strategic alignment | North Star |
| UX and product quality optimization | HEART |
| Mixed maturity org | North Star + AARRR operational layers |

## Example: B2B SaaS Product

- North Star: weekly active accounts completing core workflow
- AARRR operational metrics:
  - Acquisition: qualified signups
  - Activation: % accounts completing setup in 7 days
  - Retention: W8 retained accounts
  - Revenue: paid conversion and expansion rate
  - Referral: invited teammate activation rate
- HEART for onboarding redesign:
  - Task Success: onboarding completion rate
  - Happiness: onboarding CSAT
